==> kscreen-1.0.71_p20150824.tar.xz: kscreen-1.0.71_p20150824/plasma/plasma-applet-kscreen.desktop.cmake <==
[Desktop Entry]
Name=Quick Display Configuration
Name[bg]=Бърза настройка на екрана
Name[bs]=Brza konfiguracija ekrana
Name[ca]=Configuració ràpida de la pantalla
Name[ca@valencia]=Configuració ràpida de la pantalla
Name[cs]=Rychlé nastavení zobrazení
Name[da]=Hurtig konfiguration af skærme
Name[de]=Schnelle Anzeige-Einrichtung
Name[el]=Γρήγορη διαμόρφωση απεικόνισης
Name[en_GB]=Quick Display Configuration
Name[es]=Configuración rápida de la pantalla
Name[fi]=Näyttöasetusten pikasäätö
Name[fr]=Configuration rapide de l'affichage
Name[gl]=Configuración rápida da pantalla
Name[hu]=Gyors kijelző beállítások
Name[it]=Configurazione rapida dello schermo
Name[ko]=빠른 화면 설정
Name[mr]=त्वरीत प्रदर्शकाची संयोजना
Name[nb]=Hurtig skjermoppsett
Name[nds]=Fix-Schirminstellen
Name[nl]=Snel instellen van scherm
Name[pl]=Szybkie ustawienia wyświetlacza
Name[pt]=Configuração Rápida do Ecrã
Name[pt_BR]=Configuração rápida da tela
Name[ro]=Configurare rapidă a ecranelor
Name[ru]=Быстрая настройка экрана
Name[sk]=Rýchle nastavenie obrazovky
Name[sl]=Hitre nastavitve zaslona
Name[sv]=Snabbinställning av skärm
Name[tr]=Hızlı Ekran Yapılandırması
Name[ug]=تېز كۆرسىتىش سەپلەش
Name[uk]=Швидке налаштовування дисплея
Name[x-test]=xxQuick Display Configurationxx
Name[zh_CN]=快捷显示管理
Name[zh_TW]=快速顯示設定
Comment=Quick configuration of a new display
Comment[bg]=Бързо настройване на нов екран
Comment[bs]=Brza konfiguracija novog ekrana
Comment[ca]=Configuració ràpida d'una nova pantalla
Comment[ca@valencia]=Configuració ràpida d'una nova pantalla
Comment[cs]=Rychlé nastavení nového zobrazení
Comment[da]=Hurtig konfiguration af en ny skærm
Comment[de]=Schnelle Einrichtung einer neuen Anzeige
Comment[el]=Γρήγορη διαμόρφωση μιας νέας απεικόνισης
Comment[en_GB]=Quick configuration of a new display
Comment[es]=Configuración rápida de una nueva pantalla
Comment[fi]=Näyttöasetusten pikasäätö
Comment[fr]=Configuration rapide d'un nouvel affichage
Comment[gl]=Configura rapidamente unha nova pantalla
Comment[hu]=Egy új kijelző gyors beállítása
Comment[it]=Configurazione rapida di un nuovo schermo
Comment[ko]=새 디스플레이 빠른 설정
Comment[mr]=नवीन प्रदर्शकाची त्वरीत संयोजना
Comment[nb]=Hurtig oppsett av en ny skjerm
Comment[nds]=En nieg Schirm gau instellen
Comment[nl]=Snel instellen van een nieuwe scherm
Comment[pl]=Szybkie ustawienia nowego wyświetlacza
Comment[pt]=Configuração rápida de um novo ecrã
Comment[pt_BR]=Configuração rápida de uma nova tela
Comment[ro]=Configurare rapidă a unui nou ecran
Comment[ru]=Быстрая настройка нового экрана
Comment[sk]=Rýchle nastavenie novej obrazovky
Comment[sl]=Hitre nastavitve novega zaslona
Comment[sv]=Snabbinställning av en ny skärm
Comment[tr]=Yeni bir ekranın hızlı yapılandırması
Comment[ug]=يېڭى كۆرسەتكۈچنى تېز سەپلەيدۇ
Comment[uk]=Швидке налаштовування нового дисплея
Comment[x-test]=xxQuick configuration of a new displayxx
Comment[zh_CN]=快捷配置新显示器
Comment[zh_TW]=快速設定新的顯示

Icon=preferences-desktop-display-randr
Type=Service
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet

X-Plasma-DefaultSize=290,150
X-Plasma-NotificationArea=true
X-Plasma-ConfigPlugins=kscreen

X-KDE-Library=plasma_applet_kscreen
X-KDE-PluginInfo-Author=Dan Vrátil
X-KDE-PluginInfo-Email=dvratil@redhat.com
X-KDE-PluginInfo-Name=org.kde.plasma.kscreen
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> kscreen-5.1.95.tar.xz: kscreen-5.1.95/plasma/plasma-applet-kscreen.desktop.cmake <==
[Desktop Entry]
Name=Quick Display Configuration
Name[bg]=Бърза настройка на екрана
Name[bs]=Brza konfiguracija ekrana
Name[ca]=Configuració ràpida de la pantalla
Name[ca@valencia]=Configuració ràpida de la pantalla
Name[cs]=Rychlé nastavení zobrazení
Name[da]=Hurtig konfiguration af skærme
Name[de]=Schnelle Anzeige-Einrichtung
Name[el]=Γρήγορη διαμόρφωση απεικόνισης
Name[en_GB]=Quick Display Configuration
Name[es]=Configuración rápida de la pantalla
Name[fi]=Näyttöasetusten pikasäätö
Name[fr]=Configuration rapide de l'affichage
Name[gl]=Configuración rápida da pantalla
Name[hu]=Gyors kijelző beállítások
Name[it]=Configurazione rapida dello schermo
Name[ko]=빠른 화면 설정
Name[mr]=त्वरीत प्रदर्शकाची संयोजना
Name[nb]=Hurtig skjermoppsett
Name[nds]=Fix-Schirminstellen
Name[nl]=Snel instellen van scherm
Name[pl]=Szybka konfiguracja wyświetlacza
Name[pt]=Configuração Rápida do Ecrã
Name[pt_BR]=Configuração rápida da tela
Name[ro]=Configurare rapidă a ecranelor
Name[ru]=Быстрая настройка экрана
Name[sk]=Rýchle nastavenie obrazovky
Name[sl]=Hitre nastavitve zaslona
Name[sv]=Snabbinställning av skärm
Name[tr]=Hızlı Ekran Yapılandırması
Name[ug]=تېز كۆرسىتىش سەپلەش
Name[uk]=Швидке налаштовування дисплея
Name[x-test]=xxQuick Display Configurationxx
Name[zh_CN]=快捷显示管理
Name[zh_TW]=快速顯示設定
Comment=Quick configuration of a new display
Comment[bg]=Бързо настройване на нов екран
Comment[bs]=Brza konfiguracija novog ekrana
Comment[ca]=Configuració ràpida d'una nova pantalla
Comment[ca@valencia]=Configuració ràpida d'una nova pantalla
Comment[cs]=Rychlé nastavení nového zobrazení
Comment[da]=Hurtig konfiguration af en ny skærm
Comment[de]=Schnelle Einrichtung einer neuen Anzeige
Comment[el]=Γρήγορη διαμόρφωση μιας νέας απεικόνισης
Comment[en_GB]=Quick configuration of a new display
Comment[es]=Configuración rápida de una nueva pantalla
Comment[fi]=Näyttöasetusten pikasäätö
Comment[fr]=Configuration rapide d'un nouvel affichage
Comment[gl]=Configura rapidamente unha nova pantalla
Comment[hu]=Egy új kijelző gyors beállítása
Comment[it]=Configurazione rapida di un nuovo schermo
Comment[ko]=새 디스플레이 빠른 설정
Comment[mr]=नवीन प्रदर्शकाची त्वरीत संयोजना
Comment[nb]=Hurtig oppsett av en ny skjerm
Comment[nds]=En nieg Schirm gau instellen
Comment[nl]=Snel instellen van een nieuwe scherm
Comment[pl]=Szybka konfiguracja nowego wyświetlacza
Comment[pt]=Configuração rápida de um novo ecrã
Comment[pt_BR]=Configuração rápida de uma nova tela
Comment[ro]=Configurare rapidă a unui nou ecran
Comment[ru]=Быстрая настройка нового экрана
Comment[sk]=Rýchle nastavenie novej obrazovky
Comment[sl]=Hitre nastavitve novega zaslona
Comment[sv]=Snabbinställning av en ny skärm
Comment[tr]=Yeni bir ekranın hızlı yapılandırması
Comment[ug]=يېڭى كۆرسەتكۈچنى تېز سەپلەيدۇ
Comment[uk]=Швидке налаштовування нового дисплея
Comment[x-test]=xxQuick configuration of a new displayxx
Comment[zh_CN]=快捷配置新显示器
Comment[zh_TW]=快速設定新的顯示

Icon=preferences-desktop-display-randr
Type=Service
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet

X-Plasma-DefaultSize=290,150
X-Plasma-NotificationArea=true
X-Plasma-ConfigPlugins=kscreen

X-KDE-Library=plasma_applet_kscreen
X-KDE-PluginInfo-Author=Dan Vrátil
X-KDE-PluginInfo-Email=dvratil@redhat.com
X-KDE-PluginInfo-Name=org.kde.plasma.kscreen
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
